<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="26"/>
        <location filename="ui_mainwindow.h" line="756"/>
        <source>Network Assistant</source>
        <translation>Asystent sieci</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="86"/>
        <location filename="ui_mainwindow.h" line="799"/>
        <source>About...</source>
        <translation>O...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="109"/>
        <location filename="ui_mainwindow.h" line="803"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="177"/>
        <location filename="ui_mainwindow.h" line="805"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="184"/>
        <location filename="ui_mainwindow.h" line="807"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="219"/>
        <location filename="ui_mainwindow.h" line="770"/>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="225"/>
        <location filename="ui_mainwindow.h" line="757"/>
        <source>IP address</source>
        <translation>Adres IP</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="261"/>
        <location filename="ui_mainwindow.h" line="760"/>
        <source>Hardware detected</source>
        <translation>Wykryto sprzęt</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="280"/>
        <source>Enable</source>
        <translation>Włączone</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="303"/>
        <location filename="mainwindow.ui" line="593"/>
        <location filename="mainwindow.ui" line="706"/>
        <location filename="ui_mainwindow.h" line="761"/>
        <location filename="ui_mainwindow.h" line="774"/>
        <location filename="ui_mainwindow.h" line="780"/>
        <source>Re-scan</source>
        <translation>Skanuj ponownie</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="372"/>
        <source>Enabled</source>
        <translation>Włączony</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="377"/>
        <source>Interface</source>
        <translation>Interfejs</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="382"/>
        <source>Driver</source>
        <translation>Sterownik</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="387"/>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="392"/>
        <source>Vendor</source>
        <translation>Dostawca</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="397"/>
        <source>Product</source>
        <translation>Produkt</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="405"/>
        <source>Disable</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="419"/>
        <location filename="ui_mainwindow.h" line="762"/>
        <source>Active interface</source>
        <translation>Aktywny interfejs</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="435"/>
        <location filename="ui_mainwindow.h" line="764"/>
        <source>WiFi status</source>
        <translation>Status WiFi</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="457"/>
        <location filename="ui_mainwindow.h" line="767"/>
        <source>Unblocks all soft/hard blocked wireless devices</source>
        <translation>Odblokowuje wszystkie programowo/sprzętowo zablokowane urządzenia bezprzewodowe</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="460"/>
        <location filename="ui_mainwindow.h" line="769"/>
        <source>Unblock WiFi Devices</source>
        <translation>Odblokuj urządzenia WiFi</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="492"/>
        <location filename="ui_mainwindow.h" line="776"/>
        <source>Linux drivers</source>
        <translation>Sterowniki Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="504"/>
        <location filename="ui_mainwindow.h" line="771"/>
        <source>Associated Linux drivers</source>
        <translation>Powiązane sterowniki systemu Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="513"/>
        <location filename="ui_mainwindow.h" line="772"/>
        <source>Load Driver</source>
        <translation>Załaduj sterownik</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="576"/>
        <location filename="ui_mainwindow.h" line="773"/>
        <source>Unload Driver</source>
        <translation>Odinstaluj sterownik</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="613"/>
        <location filename="mainwindow.cpp" line="833"/>
        <location filename="ui_mainwindow.h" line="775"/>
        <source>Block Driver</source>
        <translation>Zablokuj sterownik</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="632"/>
        <location filename="ui_mainwindow.h" line="785"/>
        <source>Windows drivers</source>
        <translation>Sterowniki Windows</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="638"/>
        <location filename="ui_mainwindow.h" line="777"/>
        <source>Available Windows drivers</source>
        <translation>Dostępne sterowniki dla systemu Windows</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="672"/>
        <location filename="ui_mainwindow.h" line="778"/>
        <source>Remove Driver</source>
        <translation>Usuń sterownik</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="683"/>
        <location filename="ui_mainwindow.h" line="779"/>
        <source>Add Driver</source>
        <translation>Dodaj sterownik</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="724"/>
        <location filename="ui_mainwindow.h" line="781"/>
        <source>About NDISwrapper</source>
        <translation>Informacje o NDISwrapper</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="736"/>
        <location filename="ui_mainwindow.h" line="782"/>
        <source>Install NDISwrapper</source>
        <translation>Zainstaluj NDISwrapper</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="747"/>
        <location filename="ui_mainwindow.h" line="783"/>
        <source>In order to use Windows drivers you need first to install NDISwrapper</source>
        <translation>Aby korzystać ze sterowników Windows, musisz najpierw zainstalować NDISwrapper</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="763"/>
        <location filename="ui_mainwindow.h" line="784"/>
        <source>Uninstall NDISwrapper</source>
        <translation>Odinstaluj NDISwrapper</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="795"/>
        <location filename="ui_mainwindow.h" line="798"/>
        <source>Net diagnostics</source>
        <translation>Diagnostyka sieci</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="807"/>
        <location filename="ui_mainwindow.h" line="786"/>
        <source>Ping</source>
        <translation>Ping</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="813"/>
        <location filename="mainwindow.ui" line="933"/>
        <location filename="ui_mainwindow.h" line="787"/>
        <location filename="ui_mainwindow.h" line="793"/>
        <source>Target URL:</source>
        <translation>Docelowy adres URL:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="823"/>
        <location filename="ui_mainwindow.h" line="788"/>
        <source>Packets</source>
        <translation>Pakiety</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="868"/>
        <location filename="mainwindow.ui" line="991"/>
        <location filename="ui_mainwindow.h" line="789"/>
        <location filename="ui_mainwindow.h" line="795"/>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="885"/>
        <location filename="mainwindow.ui" line="1008"/>
        <location filename="ui_mainwindow.h" line="790"/>
        <location filename="ui_mainwindow.h" line="796"/>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="899"/>
        <location filename="mainwindow.ui" line="1022"/>
        <location filename="ui_mainwindow.h" line="791"/>
        <location filename="ui_mainwindow.h" line="797"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="927"/>
        <location filename="ui_mainwindow.h" line="792"/>
        <source>Traceroute</source>
        <translation>Traceroute</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="943"/>
        <location filename="ui_mainwindow.h" line="794"/>
        <source>Hops</source>
        <translation>Skoki</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="86"/>
        <source>IP address from router:</source>
        <translation>Adres IP z routera:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="87"/>
        <source>External IP address:</source>
        <translation>Zewnętrzny adres IP:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="124"/>
        <location filename="mainwindow.cpp" line="137"/>
        <source>Interface: %1</source>
        <translation>Interfejs: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="124"/>
        <location filename="mainwindow.cpp" line="138"/>
        <source>Driver: %1</source>
        <translation>Sterownik: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="125"/>
        <location filename="mainwindow.cpp" line="139"/>
        <source>Description: %1</source>
        <translation>Opis: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="126"/>
        <location filename="mainwindow.cpp" line="140"/>
        <source>Product: %1</source>
        <translation>Produkt: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="126"/>
        <location filename="mainwindow.cpp" line="141"/>
        <source>Vendor: %1</source>
        <translation>Dostawca: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="127"/>
        <location filename="mainwindow.cpp" line="142"/>
        <source>Enabled: %1</source>
        <translation>Włączony: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="195"/>
        <location filename="mainwindow.cpp" line="209"/>
        <location filename="mainwindow.cpp" line="223"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copy</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="197"/>
        <location filename="mainwindow.cpp" line="211"/>
        <location filename="mainwindow.cpp" line="225"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="198"/>
        <location filename="mainwindow.cpp" line="212"/>
        <location filename="mainwindow.cpp" line="226"/>
        <source>Copy &amp;All</source>
        <translation>Copy &amp;All</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="200"/>
        <location filename="mainwindow.cpp" line="214"/>
        <location filename="mainwindow.cpp" line="228"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="260"/>
        <location filename="mainwindow.cpp" line="277"/>
        <source>Traceroute not installed</source>
        <translation>Traceroute nie jest zainstalowany</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="261"/>
        <source>Traceroute is not installed, do you want to install it now?</source>
        <translation>Traceroute nie jest zainstalowany, czy chcesz go teraz zainstalować?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="267"/>
        <source>Traceroute hasn&apos;t been installed</source>
        <translation>Traceroute nie został zainstalowany</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="268"/>
        <source>Traceroute cannot be installed. This may mean you are using the LiveCD or you are unable to reach the software repository,</source>
        <translation>Nie można zainstalować Traceroute. Może to oznaczać, że korzystasz z LiveCD lub nie możesz połączyć się z repozytorium oprogramowania.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="278"/>
        <source>Traceroute is not installed and no Internet connection could be detected so it cannot be installed</source>
        <translation>Traceroute nie jest zainstalowany i nie można wykryć połączenia z Internetem, więc nie można go zainstalować</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="285"/>
        <location filename="mainwindow.cpp" line="330"/>
        <source>No destination host</source>
        <translation>Brak docelowego hosta</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="285"/>
        <location filename="mainwindow.cpp" line="330"/>
        <source>Please fill in the destination host field</source>
        <translation>Proszę wypełnić pole hosta docelowego</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="445"/>
        <source>Loaded Drivers</source>
        <translation>Załadowane sterowniki</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="454"/>
        <source>Unloaded Drivers</source>
        <translation>Niezaładowane sterowniki</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="468"/>
        <source>Blocked Drivers</source>
        <translation>Zablokowane sterowniki</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="488"/>
        <source>Blocked Broadcom Drivers</source>
        <translation>Zablokowane sterowniki Broadcom</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="510"/>
        <source>Ndiswrapper is not installed</source>
        <translation>NDISwrapper nie jest zainstalowany</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="523"/>
        <source>driver installed</source>
        <translation>sterownik zainstalowany</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="532"/>
        <source> and in use by </source>
        <translation>i w użyciu przez</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="539"/>
        <source>. Alternate driver: </source>
        <translation>. Alternatywny sterownik:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="603"/>
        <source>Driver removed from blocklist</source>
        <translation>Sterownik usunięty z listy zablokowanych</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="603"/>
        <source>Driver removed from blocklist.</source>
        <translation>Sterownik usunięty z listy zablokowanych.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="609"/>
        <source>Module blocked</source>
        <translation>Moduł zablokowany</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="763"/>
        <source>Installation successful</source>
        <translation>Instalacja zakończyła się sukcesem</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="765"/>
        <source>Error detected, could not compile ndiswrapper driver.</source>
        <translation>Wykryto błąd, nie można skompilować sterownika NDISwrapper.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="768"/>
        <source>Error detected, could not install ndiswrapper.</source>
        <translation>Wykryto błąd, nie można zainstalować NDISwrapper.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="780"/>
        <source>Error encountered while removing Ndiswrapper</source>
        <translation>Wystąpił błąd podczas usuwania NDISwrapper</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="830"/>
        <source>Unblock Driver</source>
        <translation>Odblokuj sterownik</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="862"/>
        <source>enabled</source>
        <translation>włączony</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="865"/>
        <source>disabled</source>
        <translation>wyłączony</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="868"/>
        <source>WiFi hardware switch is off</source>
        <translation>Przełącznik sprzętowy WiFi jest wyłączony</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="875"/>
        <source>Locate the Windows driver you want to add</source>
        <translation>Zlokalizuj sterownik Windows, który chcesz dodać</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="876"/>
        <source>Windows installation information file (*.inf)</source>
        <translation>Plik informacji dla instalacji systemu Windows (*.inf)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="907"/>
        <source>*.sys file not found</source>
        <translation>nie znaleziono pliku *.sys</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="908"/>
        <source>The *.sys files must be in the same location as the *.inf file. %1 cannot be found</source>
        <translation>Pliki *.sys muszą znajdować się w tej samej lokalizacji, co plik *.inf. Nie można znaleźć %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="919"/>
        <source>sys file reference not found</source>
        <translation>nie znaleziono odwołania do pliku sys</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="920"/>
        <source>The sys file for the given driver cannot be determined after parsing the inf file</source>
        <translation>Plik sys dla danego sterownika nie może zostać określony po analizie pliku inf</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="937"/>
        <source>Ndiswrapper driver removed.</source>
        <translation>Usunięto sterownik Ndiswrapper.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="945"/>
        <source>%1 Help</source>
        <translation>%1 Pomoc</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="957"/>
        <source>Could not unlock devices.
WiFi device(s) might already be unlocked.</source>
        <translation>Nie można odblokować urządzeń.
Urządzenia Wi-Fi mogą być już odblokowane.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="959"/>
        <source>WiFi devices unlocked.</source>
        <translation>Urządzenia WiFi odblokowane.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="974"/>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="975"/>
        <source>Version: </source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="976"/>
        <source>Program for troubleshooting and configuring network for antiX Linux</source>
        <translation>Program do rozwiązywania problemów i konfiguracji sieci dla antiX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="978"/>
        <source>Copyright (c) MEPIS LLC and MX Linux</source>
        <translation>Prawa autorskie © MEPIS LLC i MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="979"/>
        <source>%1 License</source>
        <translation>%1 Licencja</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1005"/>
        <source>Driver loaded successfully</source>
        <translation>Sterownik został pomyślnie załadowany</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1020"/>
        <source>Driver unloaded successfully</source>
        <translation>Sterownik został pomyślnie odinstalowany</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="about.cpp" line="52"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <location filename="about.cpp" line="53"/>
        <location filename="about.cpp" line="63"/>
        <source>Changelog</source>
        <translation>Dziennik zmian</translation>
    </message>
    <message>
        <location filename="about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="about.cpp" line="76"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="main.cpp" line="70"/>
        <location filename="main.cpp" line="78"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="main.cpp" line="71"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Wygląda na to, że jesteś zalogowany jako root, wyloguj się i zaloguj jako zwykły użytkownik, aby korzystać z tego programu.</translation>
    </message>
    <message>
        <location filename="main.cpp" line="79"/>
        <source>You must run this program with admin access.</source>
        <translation>Musisz uruchomić ten program z uprawnieniami administratora.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="624"/>
        <source>Could not load </source>
        <translation>Nie można załadować</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="649"/>
        <source>Could not unload </source>
        <translation>Nie można odinstalować</translation>
    </message>
</context>
</TS>